====================================
bisos.graphviz: Seeded-PyCS Graphviz
====================================

.. contents::
   :depth: 3
..

Overview
========

bisos.graphviz (Seeded-PyCS Graphviz) is Python graphviz wrapped into
BISOS Command-Services and Seed Machinaries.

bisos.graphviz is a python package that uses the PyCS-Framework
(`bisos.PyCS <https://github.com/bisos-pip/pycs>`__) for processing
graphviz specifications. It is a layer on top of Python Graphviz —
https://github.com/xflr6/graphviz — which provides a python interface to
the DOT language of the Graphviz graph drawing software. It is a
BISOS-Capability and a Standalone-BISOS-Package.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact
